{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#FASTQReadPairType.yml/FASTQReadPairType",
                            "fields": [
                                {
                                    "name": "#FASTQReadPairType.yml/FASTQReadPairType/name",
                                    "type": "string"
                                },
                                {
                                    "name": "#FASTQReadPairType.yml/FASTQReadPairType/read1_files",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                },
                                {
                                    "name": "#FASTQReadPairType.yml/FASTQReadPairType/read2_files",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/GATKJar"
                },
                {
                    "type": "File",
                    "id": "#main/bait_interval_list"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#main/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/knownSites"
                },
                {
                    "type": "string",
                    "id": "#main/library"
                },
                {
                    "type": "string",
                    "id": "#main/platform"
                },
                {
                    "type": "#FASTQReadPairType.yml/FASTQReadPairType",
                    "id": "#main/read_pair"
                },
                {
                    "type": "File",
                    "id": "#main/reference_genome"
                },
                {
                    "type": "File",
                    "id": "#main/resource_dbsnp"
                },
                {
                    "type": "File",
                    "id": "#main/target_interval_list"
                },
                {
                    "type": "int",
                    "id": "#main/threads"
                }
            ],
            "steps": [
                {
                    "run": "#picard-CollectHsMetrics.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 4000,
                            "outdirMin": 12000,
                            "tmpdirMin": 12000
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/bait_interval_list",
                            "id": "#main/collect_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#main/mark_duplicates/output_dedup_bam_file",
                            "id": "#main/collect_hs_metrics/input_file"
                        },
                        {
                            "source": "#main/generate_sample_filenames/hs_metrics_output_filename",
                            "id": "#main/collect_hs_metrics/output_filename"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/collect_hs_metrics/reference_sequence"
                        },
                        {
                            "source": "#main/target_interval_list",
                            "id": "#main/collect_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/collect_hs_metrics/output_hs_metrics_file"
                    ],
                    "id": "#main/collect_hs_metrics"
                },
                {
                    "run": "#concat-gz-files.cwl",
                    "scatter": [
                        "#main/combine_reads/files",
                        "#main/combine_reads/output_filename"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/file_pair_details/reads",
                            "id": "#main/combine_reads/files"
                        },
                        {
                            "source": "#main/generate_sample_filenames/combined_reads_output_filenames",
                            "id": "#main/combine_reads/output_filename"
                        }
                    ],
                    "out": [
                        "#main/combine_reads/output"
                    ],
                    "id": "#main/combine_reads"
                },
                {
                    "run": "#extract-named-file-pair-details.cwl",
                    "in": [
                        {
                            "source": "#main/library",
                            "id": "#main/file_pair_details/library"
                        },
                        {
                            "source": "#main/platform",
                            "id": "#main/file_pair_details/platform"
                        },
                        {
                            "source": "#main/read_pair",
                            "id": "#main/file_pair_details/read_pair"
                        }
                    ],
                    "out": [
                        "#main/file_pair_details/reads",
                        "#main/file_pair_details/read_pair_name",
                        "#main/file_pair_details/read_group_header"
                    ],
                    "id": "#main/file_pair_details"
                },
                {
                    "run": "#generate-sample-filenames.cwl",
                    "in": [
                        {
                            "source": "#main/file_pair_details/read_pair_name",
                            "id": "#main/generate_sample_filenames/sample_name"
                        }
                    ],
                    "out": [
                        "#main/generate_sample_filenames/combined_reads_output_filenames",
                        "#main/generate_sample_filenames/mapped_reads_output_filename",
                        "#main/generate_sample_filenames/sorted_reads_output_filename",
                        "#main/generate_sample_filenames/dedup_reads_output_filename",
                        "#main/generate_sample_filenames/dedup_metrics_output_filename",
                        "#main/generate_sample_filenames/recal_reads_output_filename",
                        "#main/generate_sample_filenames/recal_table_output_filename",
                        "#main/generate_sample_filenames/raw_variants_output_filename",
                        "#main/generate_sample_filenames/haplotypes_bam_output_filename",
                        "#main/generate_sample_filenames/hs_metrics_output_filename"
                    ],
                    "id": "#main/generate_sample_filenames"
                },
                {
                    "run": "#bwa-mem-samtools.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": "$(inputs.threads)",
                            "ramMin": 16000,
                            "outdirMin": 12000,
                            "tmpdirMin": 12000
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/generate_sample_filenames/mapped_reads_output_filename",
                            "id": "#main/map/output_filename"
                        },
                        {
                            "source": "#main/file_pair_details/read_group_header",
                            "id": "#main/map/read_group_header"
                        },
                        {
                            "source": "#main/trim/trimmed_reads",
                            "id": "#main/map/reads"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/map/reference"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/map/threads"
                        }
                    ],
                    "out": [
                        "#main/map/output"
                    ],
                    "id": "#main/map"
                },
                {
                    "run": "#picard-MarkDuplicates.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 4000,
                            "outdirMin": 12000,
                            "tmpdirMin": 12000
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/sort/sorted",
                            "id": "#main/mark_duplicates/input_file"
                        },
                        {
                            "source": "#main/generate_sample_filenames/dedup_metrics_output_filename",
                            "id": "#main/mark_duplicates/metrics_filename"
                        },
                        {
                            "source": "#main/generate_sample_filenames/dedup_reads_output_filename",
                            "id": "#main/mark_duplicates/output_filename"
                        }
                    ],
                    "out": [
                        "#main/mark_duplicates/output_dedup_bam_file",
                        "#main/mark_duplicates/output_metrics_file"
                    ],
                    "id": "#main/mark_duplicates"
                },
                {
                    "run": "#fastqc.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 4,
                            "ramMin": 2500
                        }
                    ],
                    "scatter": "#main/qc/input_fastq_file",
                    "in": [
                        {
                            "source": "#main/combine_reads/output",
                            "id": "#main/qc/input_fastq_file"
                        },
                        {
                            "default": 4,
                            "id": "#main/qc/threads"
                        }
                    ],
                    "out": [
                        "#main/qc/output_qc_report"
                    ],
                    "id": "#main/qc"
                },
                {
                    "run": "#GATK-BaseRecalibrator.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 8,
                            "ramMin": 4096
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/GATKJar",
                            "id": "#main/recalibrate_01_analyze/GATKJar"
                        },
                        {
                            "default": 8,
                            "id": "#main/recalibrate_01_analyze/cpu_threads"
                        },
                        {
                            "source": "#main/mark_duplicates/output_dedup_bam_file",
                            "id": "#main/recalibrate_01_analyze/inputBam_BaseRecalibrator"
                        },
                        {
                            "source": "#main/interval_padding",
                            "id": "#main/recalibrate_01_analyze/interval_padding"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/recalibrate_01_analyze/intervals"
                        },
                        {
                            "source": "#main/knownSites",
                            "id": "#main/recalibrate_01_analyze/knownSites"
                        },
                        {
                            "source": "#main/generate_sample_filenames/recal_table_output_filename",
                            "id": "#main/recalibrate_01_analyze/outputfile_BaseRecalibrator"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/recalibrate_01_analyze/reference"
                        }
                    ],
                    "out": [
                        "#main/recalibrate_01_analyze/output_baseRecalibrator"
                    ],
                    "id": "#main/recalibrate_01_analyze"
                },
                {
                    "run": "#GATK-PrintReads.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 8,
                            "ramMin": 4096
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/GATKJar",
                            "id": "#main/recalibrate_02_apply/GATKJar"
                        },
                        {
                            "default": 8,
                            "id": "#main/recalibrate_02_apply/cpu_threads"
                        },
                        {
                            "source": "#main/mark_duplicates/output_dedup_bam_file",
                            "id": "#main/recalibrate_02_apply/inputBam_printReads"
                        },
                        {
                            "source": "#main/recalibrate_01_analyze/output_baseRecalibrator",
                            "id": "#main/recalibrate_02_apply/input_baseRecalibrator"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/recalibrate_02_apply/intervals"
                        },
                        {
                            "source": "#main/generate_sample_filenames/recal_reads_output_filename",
                            "id": "#main/recalibrate_02_apply/outputfile_printReads"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/recalibrate_02_apply/reference"
                        }
                    ],
                    "out": [
                        "#main/recalibrate_02_apply/output_printReads"
                    ],
                    "id": "#main/recalibrate_02_apply"
                },
                {
                    "run": "#picard-SortSam.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 4000,
                            "outdirMin": 12000,
                            "tmpdirMin": 12000
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/map/output",
                            "id": "#main/sort/input_file"
                        },
                        {
                            "source": "#main/generate_sample_filenames/sorted_reads_output_filename",
                            "id": "#main/sort/output_filename"
                        }
                    ],
                    "out": [
                        "#main/sort/sorted"
                    ],
                    "id": "#main/sort"
                },
                {
                    "run": "#trim_galore.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 4,
                            "ramMin": 8000
                        }
                    ],
                    "in": [
                        {
                            "default": true,
                            "id": "#main/trim/paired"
                        },
                        {
                            "source": "#main/combine_reads/output",
                            "id": "#main/trim/reads"
                        }
                    ],
                    "out": [
                        "#main/trim/trimmed_reads",
                        "#main/trim/trim_reports"
                    ],
                    "id": "#main/trim"
                },
                {
                    "run": "#GATK-HaplotypeCaller.cwl",
                    "requirements": [
                        {
                            "class": "ResourceRequirement",
                            "coresMin": 1,
                            "ramMin": 16384
                        }
                    ],
                    "in": [
                        {
                            "source": "#main/GATKJar",
                            "id": "#main/variant_calling/GATKJar"
                        },
                        {
                            "source": "#main/generate_sample_filenames/haplotypes_bam_output_filename",
                            "id": "#main/variant_calling/bamOutput"
                        },
                        {
                            "source": "#main/resource_dbsnp",
                            "id": "#main/variant_calling/dbsnp"
                        },
                        {
                            "default": "GVCF",
                            "id": "#main/variant_calling/emitRefConfidence"
                        },
                        {
                            "default": [
                                "StandardAnnotation",
                                "AS_StandardAnnotation"
                            ],
                            "id": "#main/variant_calling/group"
                        },
                        {
                            "source": "#main/recalibrate_02_apply/output_printReads",
                            "id": "#main/variant_calling/inputBam_HaplotypeCaller"
                        },
                        {
                            "source": "#main/interval_padding",
                            "id": "#main/variant_calling/interval_padding"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/variant_calling/intervals"
                        },
                        {
                            "source": "#main/generate_sample_filenames/raw_variants_output_filename",
                            "id": "#main/variant_calling/outputfile_HaplotypeCaller"
                        },
                        {
                            "source": "#main/reference_genome",
                            "id": "#main/variant_calling/reference"
                        }
                    ],
                    "out": [
                        "#main/variant_calling/output_HaplotypeCaller",
                        "#main/variant_calling/output_HaplotypesBam"
                    ],
                    "id": "#main/variant_calling"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/output_qc_report",
                    "id": "#main/fastqc_reports"
                },
                {
                    "type": "File",
                    "outputSource": "#main/variant_calling/output_HaplotypesBam",
                    "doc": "BAM file containing assembled haplotypes and locally realigned reads",
                    "id": "#main/haplotypes_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_hs_metrics/output_hs_metrics_file",
                    "id": "#main/hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/mark_duplicates/output_dedup_bam_file",
                    "id": "#main/markduplicates_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#main/variant_calling/output_HaplotypeCaller",
                    "doc": "VCF file from per sample variant calling",
                    "id": "#main/raw_variants"
                },
                {
                    "type": "File",
                    "outputSource": "#main/recalibrate_02_apply/output_printReads",
                    "id": "#main/recalibrated_reads"
                },
                {
                    "type": "File",
                    "outputSource": "#main/recalibrate_01_analyze/output_baseRecalibrator",
                    "id": "#main/recalibration_table"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/trim/trim_reports",
                    "id": "#main/trim_reports"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envName": "PATH",
                            "envValue": "/usr/local/bin/:/usr/bin:/bin"
                        }
                    ],
                    "id": "#envvar-global.yml"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/gatk-base:3"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "3.8"
                            ],
                            "package": "gatk",
                            "https://schema.org/citation": "https://dx.doi.org/10.1038/ng.806"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-jar"
                    },
                    "id": "#GATK-BaseRecalibrator.cwl/GATKJar"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--binary_tag_name"
                    },
                    "doc": "the binary tag covariate name if using it",
                    "id": "#GATK-BaseRecalibrator.cwl/binary_tag_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--BQSR"
                    },
                    "doc": "Input covariates table file for on-the-fly base quality score recalibration",
                    "id": "#GATK-BaseRecalibrator.cwl/bqsr"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--bqsrBAQGapOpenPenalty"
                    },
                    "doc": "BQSR BAQ gap open penalty (Phred Scaled). Default value is 40. 30 is perhaps better for whole genome call sets",
                    "id": "#GATK-BaseRecalibrator.cwl/bqsrBAQGapOpenPenalty"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--covariate"
                    },
                    "doc": "One or more covariates to be used in the recalibration. Can be specified multiple times",
                    "id": "#GATK-BaseRecalibrator.cwl/covariate"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "controls the number of CPU threads allocated to each data thread",
                    "default": 8,
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-nct"
                    },
                    "id": "#GATK-BaseRecalibrator.cwl/cpu_threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--deletions_default_quality"
                    },
                    "doc": "default quality for the base deletions covariate",
                    "id": "#GATK-BaseRecalibrator.cwl/deletions_default_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--indels_context_size"
                    },
                    "doc": "Size of the k-mer context to be used for base insertions and deletions",
                    "id": "#GATK-BaseRecalibrator.cwl/indels_context_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-I"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "doc": "bam file produced after indelRealigner",
                    "id": "#GATK-BaseRecalibrator.cwl/inputBam_BaseRecalibrator"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--insertions_default_quality"
                    },
                    "doc": "default quality for the base insertions covariate",
                    "id": "#GATK-BaseRecalibrator.cwl/insertions_default_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--interval_padding"
                    },
                    "doc": "Amount of padding (in bp) to add to each interval",
                    "id": "#GATK-BaseRecalibrator.cwl/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "--intervals"
                            }
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GATK-BaseRecalibrator.cwl/intervals"
                },
                {
                    "type": "string",
                    "default": "-Xmx4g",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#GATK-BaseRecalibrator.cwl/java_arg"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "--knownSites"
                            }
                        }
                    ],
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Any number of VCF files representing known SNPs and/or indels. Could be e.g. dbSNP and/or official 1000 Genomes indel calls. SNPs in these files will be ignored unless the --mismatchFraction argument is used. optional parameter.",
                    "id": "#GATK-BaseRecalibrator.cwl/knownSites"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--list"
                    },
                    "doc": "List the available covariates and exit",
                    "id": "#GATK-BaseRecalibrator.cwl/list"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--lowMemoryMode"
                    },
                    "doc": "Reduce memory usage in multi-threaded code at the expense of threading efficiency",
                    "id": "#GATK-BaseRecalibrator.cwl/lowMemoryMode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--low_quality_tail"
                    },
                    "doc": "minimum quality for the bases in the tail of the reads to be considered",
                    "id": "#GATK-BaseRecalibrator.cwl/low_quality_tail"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--maximum_cycle_value"
                    },
                    "doc": "The maximum cycle value permitted for the Cycle covariate",
                    "id": "#GATK-BaseRecalibrator.cwl/maximum_cycle_value"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--mismatches_context_size"
                    },
                    "doc": "Size of the k-mer context to be used for base mismatches",
                    "id": "#GATK-BaseRecalibrator.cwl/mismatches_context_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--mismatches_default_quality"
                    },
                    "doc": "default quality for the base mismatches covariate",
                    "id": "#GATK-BaseRecalibrator.cwl/mismatches_default_quality"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--no_standard_covs"
                    },
                    "doc": "Do not use the standard set of covariates, but rather just the ones listed using the -cov argument",
                    "id": "#GATK-BaseRecalibrator.cwl/no_standard_covs"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--out"
                    },
                    "doc": "The output recalibration table file to create",
                    "id": "#GATK-BaseRecalibrator.cwl/out"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-o"
                    },
                    "doc": "name of the output file from baseRecalibrator",
                    "id": "#GATK-BaseRecalibrator.cwl/outputfile_BaseRecalibrator"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--quantizing_levels"
                    },
                    "doc": "Sort the rows in the tables of reports. Whether GATK report tables should have rows in sorted order, starting from leftmost column",
                    "id": "#GATK-BaseRecalibrator.cwl/quantizing_levels"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-R"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#GATK-BaseRecalibrator.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--run_without_dbsnp_potentially_ruining_quality"
                    },
                    "doc": "If specified, allows the recalibrator to be used without a dbsnp rod. Very unsafe and for expert users only.",
                    "id": "#GATK-BaseRecalibrator.cwl/run_without_dbsnp_potentially_ruining_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--solid_nocall_strategy"
                    },
                    "doc": "Defines the behavior of the recalibrator when it encounters no calls in the color space. Options = THROW_EXCEPTION, LEAVE_READ_UNRECALIBRATED, or PURGE_READ",
                    "id": "#GATK-BaseRecalibrator.cwl/solid_nocall_strategy"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--solid_recal_mode"
                    },
                    "doc": "How should we recalibrate solid bases in which the reference was inserted? Options = DO_NOTHING, SET_Q_ZERO, SET_Q_ZERO_BASE_N, or REMOVE_REF_BIAS",
                    "id": "#GATK-BaseRecalibrator.cwl/solid_recal_mode"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--sort_by_all_columns"
                    },
                    "doc": "Sort the rows in the tables of reports. Whether GATK report tables should have rows in sorted order, starting from leftmost column",
                    "id": "#GATK-BaseRecalibrator.cwl/sort_by_all_columns"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputfile_BaseRecalibrator)"
                    },
                    "id": "#GATK-BaseRecalibrator.cwl/output_baseRecalibrator"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "position": 0,
                    "separate": false,
                    "prefix": "-Djava.io.tmpdir="
                },
                {
                    "valueFrom": "BaseRecalibrator",
                    "position": 2,
                    "prefix": "-T"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "doc": "GATK-BaseRecalibrator.cwl is developed for CWL consortium\nIt generate base recalibration table to compensate for systematic errors in basecalling confidences\n  Usage: java -jar GenomeAnalysisTK.jar -T BaseRecalibrator -R reference.fasta -I my_reads.bam -knownSites latest_dbsnp.vcf -o recal_data.table.\n",
            "id": "#GATK-BaseRecalibrator.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "$import": "#envvar-global.yml"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/gatk-base:3"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "3.8"
                            ],
                            "package": "gatk",
                            "https://schema.org/citation": "https://dx.doi.org/10.1038/ng.806"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--indelSizeToEliminateInRefModel"
                    },
                    "doc": "The size of an indel to check for in the reference model",
                    "id": "#GATK-HaplotypeCaller.cwl/ERCIS"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-jar"
                    },
                    "id": "#GATK-HaplotypeCaller.cwl/GATKJar"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Input prior for calls",
                    "id": "#GATK-HaplotypeCaller.cwl/GVCFGQBands"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--activeProbabilityThreshold"
                    },
                    "doc": "Threshold for the probability of a profile state being active.",
                    "id": "#GATK-HaplotypeCaller.cwl/activeProbabilityThreshold"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--activeRegionExtension"
                    },
                    "doc": "The active region extension; if not provided defaults to Walker annotated default",
                    "id": "#GATK-HaplotypeCaller.cwl/activeRegionExtension"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--activeRegionMaxSize"
                    },
                    "doc": "The active region maximum size; if not provided defaults to Walker annotated default",
                    "id": "#GATK-HaplotypeCaller.cwl/activeRegionMaxSize"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--activeRegionOut"
                    },
                    "doc": "Output the active region to this IGV formatted file",
                    "id": "#GATK-HaplotypeCaller.cwl/activeRegionOut"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--activityProfileOut"
                    },
                    "doc": "Output the raw activity profile results in IGV format",
                    "id": "#GATK-HaplotypeCaller.cwl/activityProfileOut"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--allSitePLs"
                    },
                    "doc": "Annotate all sites with PLs",
                    "id": "#GATK-HaplotypeCaller.cwl/allSitePLs"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "The set of alleles at which to genotype when --genotyping_mode is GENOTYPE_GIVEN_ALLELES",
                    "id": "#GATK-HaplotypeCaller.cwl/alleles"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--allowNonUniqueKmersInRef"
                    },
                    "doc": "Allow graphs that have non-unique kmers in the reference",
                    "id": "#GATK-HaplotypeCaller.cwl/allowNonUniqueKmersInRef"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--annotateNDA"
                    },
                    "doc": "If provided, we will annotate records with the number of alternate alleles that were discovered (but not necessarily genotyped) at a given site",
                    "id": "#GATK-HaplotypeCaller.cwl/annotateNDA"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "One or more specific annotations to apply to variant calls",
                    "id": "#GATK-HaplotypeCaller.cwl/annotation"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--bamOutput"
                    },
                    "doc": "File to which assembled haplotypes should be written",
                    "id": "#GATK-HaplotypeCaller.cwl/bamOutput"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--bamWriterType"
                    },
                    "doc": "Which haplotypes should be written to the BAM.",
                    "id": "#GATK-HaplotypeCaller.cwl/bamWriterType"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--consensus"
                    },
                    "doc": "The sigma of the band pass filter Gaussian kernel; if not provided defaults to Walker annotated default",
                    "id": "#GATK-HaplotypeCaller.cwl/bandPassSigma"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "comp binds reference ordered data. This argument supports ROD files of the following types BCF2, VCF, VCF3",
                    "id": "#GATK-HaplotypeCaller.cwl/comp"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--consensus"
                    },
                    "doc": "Print out very verbose debug information about each triggering active region",
                    "id": "#GATK-HaplotypeCaller.cwl/consensus"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--contamination_fraction_to_filter"
                    },
                    "doc": "Tab-separated File containing fraction of contamination in sequencing data (per sample) to aggressively remove. Format should be \"\" (Contamination is double) per line; No header.",
                    "id": "#GATK-HaplotypeCaller.cwl/contamination"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "controls the number of CPU threads allocated to each data thread",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-nct"
                    },
                    "id": "#GATK-HaplotypeCaller.cwl/cpu_threads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--dbsnp"
                    },
                    "doc": "latest_dbsnp.vcf set of known indels",
                    "id": "#GATK-HaplotypeCaller.cwl/dbsnp"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--debug"
                    },
                    "doc": "Print out very verbose debug information about each triggering active region",
                    "id": "#GATK-HaplotypeCaller.cwl/debug"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--disableOptimizations"
                    },
                    "doc": "Dont skip calculations in ActiveRegions with no variants",
                    "id": "#GATK-HaplotypeCaller.cwl/disableOptimizations"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--doNotRunPhysicalPhasing"
                    },
                    "doc": "As of GATK 3.3, HaplotypeCaller outputs physical (read-based) information (see version 3.3 release notes and documentation for details). This argument disables that behavior.",
                    "id": "#GATK-HaplotypeCaller.cwl/doNotRunPhysicalPhasing"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--dontIncreaseKmerSizesForCycles"
                    },
                    "doc": "Disable iterating over kmer sizes when graph cycles are detected",
                    "id": "#GATK-HaplotypeCaller.cwl/dontIncreaseKmerSizesForCycles"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--dontTrimActiveRegions"
                    },
                    "doc": "If specified, we will not trim down the active region from the full region (active + extension) to just the active interval for genotyping",
                    "id": "#GATK-HaplotypeCaller.cwl/dontTrimActiveRegions"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--emitRefConfidence"
                    },
                    "doc": "Mode for emitting reference confidence scores",
                    "id": "#GATK-HaplotypeCaller.cwl/emitRefConfidence"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "One or more specific annotations to exclude",
                    "id": "#GATK-HaplotypeCaller.cwl/excludeAnnotation"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--forceActive"
                    },
                    "doc": "If provided, all bases will be tagged as active",
                    "id": "#GATK-HaplotypeCaller.cwl/forceActive"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--gcpHMM"
                    },
                    "doc": "Flat gap continuation penalty for use in the Pair HMM",
                    "id": "#GATK-HaplotypeCaller.cwl/gcpHMM"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--genotyping_mode"
                    },
                    "doc": "The --genotyping_mode argument is an enumerated type (GenotypingOutputMode), which can have one of the following values",
                    "id": "#GATK-HaplotypeCaller.cwl/genotyping_mode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--phredScaledGlobalReadMismappingRate"
                    },
                    "doc": "The global assumed mismapping rate for reads",
                    "id": "#GATK-HaplotypeCaller.cwl/globalMAPQ"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--graphOutput"
                    },
                    "doc": "Write debug assembly graph information to this file",
                    "id": "#GATK-HaplotypeCaller.cwl/graphOutput"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--group"
                        }
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "One or more classes/groups of annotations to apply to variant calls",
                    "id": "#GATK-HaplotypeCaller.cwl/group"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--heterozygosity"
                    },
                    "doc": "Heterozygosity for indel calling",
                    "id": "#GATK-HaplotypeCaller.cwl/heterozygosity"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--indel_heterozygosity"
                    },
                    "doc": "Heterozygosity for indel calling",
                    "id": "#GATK-HaplotypeCaller.cwl/indel_heterozygosity"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-I"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "doc": "bam file produced after printReads",
                    "id": "#GATK-HaplotypeCaller.cwl/inputBam_HaplotypeCaller"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "double"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Input prior for calls",
                    "id": "#GATK-HaplotypeCaller.cwl/input_prior"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--interval_padding"
                    },
                    "doc": "Amount of padding (in bp) to add to each interval",
                    "id": "#GATK-HaplotypeCaller.cwl/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--intervals"
                    },
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GATK-HaplotypeCaller.cwl/intervals"
                },
                {
                    "type": "string",
                    "default": "-Xmx4g",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#GATK-HaplotypeCaller.cwl/java_arg"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Kmer size to use in the read threading assembler",
                    "id": "#GATK-HaplotypeCaller.cwl/kmerSize"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--maxNumHaplotypesInPopulation"
                    },
                    "doc": "Maximum number of haplotypes to consider for your population",
                    "id": "#GATK-HaplotypeCaller.cwl/maxNumHaplotypesInPopulation"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--maxReadsInRegionPerSample"
                    },
                    "doc": "Maximum reads in an active region",
                    "id": "#GATK-HaplotypeCaller.cwl/maxReadsInRegionPerSample"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--max_alternate_alleles"
                    },
                    "doc": "Maximum number of alternate alleles to genotype",
                    "id": "#GATK-HaplotypeCaller.cwl/max_alternate_alleles"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--minDanglingBranchLength"
                    },
                    "doc": "Minimum length of a dangling branch to attempt recovery",
                    "id": "#GATK-HaplotypeCaller.cwl/minDanglingBranchLength"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--minPruning"
                    },
                    "doc": "Minimum support to not prune paths in the graph",
                    "id": "#GATK-HaplotypeCaller.cwl/minPruning"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--minReadsPerAlignmentStart"
                    },
                    "doc": "Minimum number of reads sharing the same alignment start for each genomic location in an active region",
                    "id": "#GATK-HaplotypeCaller.cwl/minReadsPerAlignmentStart"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--min_base_quality_score"
                    },
                    "doc": "Minimum base quality required to consider a base for calling",
                    "id": "#GATK-HaplotypeCaller.cwl/min_base_quality_score"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--numPruningSamples"
                    },
                    "doc": "Number of samples that must pass the minPruning threshold",
                    "id": "#GATK-HaplotypeCaller.cwl/numPruningSamples"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--output_mode"
                    },
                    "doc": "The PCR indel model to use",
                    "id": "#GATK-HaplotypeCaller.cwl/output_mode"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-o"
                    },
                    "doc": "name of the output file from HaplotypeCaller",
                    "id": "#GATK-HaplotypeCaller.cwl/outputfile_HaplotypeCaller"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--pcr_indel_model"
                    },
                    "doc": "The PCR indel model to use",
                    "id": "#GATK-HaplotypeCaller.cwl/pcr_indel_model"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-R"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#GATK-HaplotypeCaller.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--sample_name"
                    },
                    "doc": "Use additional trigger on variants found in an external alleles file",
                    "id": "#GATK-HaplotypeCaller.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--sample_ploidy"
                    },
                    "doc": "Use additional trigger on variants found in an external alleles file",
                    "id": "#GATK-HaplotypeCaller.cwl/sample_ploidy"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--standard_min_confidence_threshold_for_calling"
                    },
                    "doc": "The minimum phred-scaled confidence threshold at which variants should be called",
                    "id": "#GATK-HaplotypeCaller.cwl/stand_call_conf"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--standard_min_confidence_threshold_for_emitting"
                    },
                    "doc": "The minimum phred-scaled confidence threshold at which variants should be emitted (and filtered with LowQual if less than the calling threshold)",
                    "id": "#GATK-HaplotypeCaller.cwl/stand_emit_conf"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--useAllelesTrigger"
                    },
                    "doc": "Use additional trigger on variants found in an external alleles file",
                    "id": "#GATK-HaplotypeCaller.cwl/useAllelesTrigger"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--useFilteredReadsForAnnotations"
                    },
                    "doc": "Use the contamination-filtered read maps for the purposes of annotating variants",
                    "id": "#GATK-HaplotypeCaller.cwl/useFilteredReadsForAnnotations"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--variant_index_parameter"
                    },
                    "doc": "Index parameter, needed by emitRefConfidence GVCF if output extension not .g.vcf",
                    "id": "#GATK-HaplotypeCaller.cwl/variant_index_parameter"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--variant_index_type"
                    },
                    "doc": "Index type, needed by emitRefConfidence GVCF if output extension not .g.vcf",
                    "id": "#GATK-HaplotypeCaller.cwl/variant_index_type"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputfile_HaplotypeCaller)"
                    },
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#GATK-HaplotypeCaller.cwl/output_HaplotypeCaller"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bamOutput)"
                    },
                    "id": "#GATK-HaplotypeCaller.cwl/output_HaplotypesBam"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "position": 0,
                    "separate": false,
                    "prefix": "-Djava.io.tmpdir="
                },
                {
                    "valueFrom": "HaplotypeCaller",
                    "position": 2,
                    "prefix": "-T"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "doc": "GATK-RealignTargetCreator.cwl is developed for CWL consortium\nCall germline SNPs and indels via local re-assembly of haplotypes\n",
            "id": "#GATK-HaplotypeCaller.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "$import": "#envvar-global.yml"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/gatk-base:3"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "3.8"
                            ],
                            "package": "gatk",
                            "https://schema.org/citation": "https://dx.doi.org/10.1038/ng.806"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-jar"
                    },
                    "id": "#GATK-PrintReads.cwl/GATKJar"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "controls the number of CPU threads allocated to each data thread",
                    "default": 8,
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-nct"
                    },
                    "id": "#GATK-PrintReads.cwl/cpu_threads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-I"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "doc": "bam file produced after indelRealigner",
                    "id": "#GATK-PrintReads.cwl/inputBam_printReads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-BQSR"
                    },
                    "doc": "the recalibration table produced by BaseRecalibration",
                    "id": "#GATK-PrintReads.cwl/input_baseRecalibrator"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--interval_padding"
                    },
                    "doc": "Amount of padding (in bp) to add to each interval",
                    "id": "#GATK-PrintReads.cwl/interval_padding"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "--intervals"
                            }
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GATK-PrintReads.cwl/intervals"
                },
                {
                    "type": "string",
                    "default": "-Xmx4g",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#GATK-PrintReads.cwl/java_arg"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--number"
                    },
                    "doc": "Exclude all reads with this platform from the output",
                    "id": "#GATK-PrintReads.cwl/number"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-o"
                    },
                    "doc": "name of the output file from indelRealigner",
                    "id": "#GATK-PrintReads.cwl/outputfile_printReads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--platform"
                    },
                    "doc": "Exclude all reads with this platform from the output",
                    "id": "#GATK-PrintReads.cwl/platform"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--readGroup"
                    },
                    "doc": "Exclude all reads with this read group from the output",
                    "id": "#GATK-PrintReads.cwl/readGroup"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-R"
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#GATK-PrintReads.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#GATK-PrintReads.cwl/sample_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "Sample name to be included in the analysis. Can be specified multiple times.",
                    "id": "#GATK-PrintReads.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--simplify"
                    },
                    "doc": "Erase all extra attributes in the read but keep the read group information",
                    "id": "#GATK-PrintReads.cwl/simplify"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputfile_printReads)"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#GATK-PrintReads.cwl/output_printReads"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "position": 0,
                    "separate": false,
                    "prefix": "-Djava.io.tmpdir="
                },
                {
                    "valueFrom": "PrintReads",
                    "position": 2,
                    "prefix": "-T"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "doc": "GATK-RealignTargetCreator.cwl is developed for CWL consortium\nPrints all reads that have a mapping quality above zero\n  Usage: java -Xmx4g -jar GenomeAnalysisTK.jar -T PrintReads -R reference.fasta -I input1.bam -I input2.bam -o output.bam --read_filter MappingQualityZero\n",
            "id": "#GATK-PrintReads.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "$import": "#envvar-global.yml"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/bwa-samtools:0.7.12_1.2.1-254-6462e34"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "0.7.12"
                            ],
                            "package": "bwa",
                            "https://schema.org/citation": "https://dx.doi.org/10.1093/bioinformatics/btp324"
                        },
                        {
                            "version": [
                                "1.2-242-g4d56437"
                            ],
                            "package": "samtools",
                            "https://schema.org/citation": "https://doi.org/10.1093/bioinformatics/btp352"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-I",
                        "itemSeparator": ","
                    },
                    "id": "#bwa-mem-samtools.cwl/min_std_max_min"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-k"
                    },
                    "doc": "-k INT        minimum seed length [19]",
                    "id": "#bwa-mem-samtools.cwl/minimum_seed_length"
                },
                {
                    "type": "string",
                    "id": "#bwa-mem-samtools.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-R"
                    },
                    "doc": "-R STR        read group header line such as '@RG\\tID:foo\\tSM:bar' [null]",
                    "id": "#bwa-mem-samtools.cwl/read_group_header"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bwa-mem-samtools.cwl/reads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#bwa-mem-samtools.cwl/reference"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-t"
                    },
                    "doc": "-t INT        number of threads [1]",
                    "id": "#bwa-mem-samtools.cwl/threads"
                }
            ],
            "stdout": "$(inputs.output_filename)",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#bwa-mem-samtools.cwl/output"
                }
            ],
            "baseCommand": [
                "bwamem-to-samtools.sh"
            ],
            "doc": "Usage: bwa mem [options] <idxbase> <in1.fq> [in2.fq]\n\nAlgorithm options:\n       -w INT        band width for banded alignment [100]\n       -d INT        off-diagonal X-dropoff [100]\n       -r FLOAT      look for internal seeds inside a seed longer than {-k} * FLOAT [1.5]\n       -y INT        seed occurrence for the 3rd round seeding [20]\n       -c INT        skip seeds with more than INT occurrences [500]\n       -D FLOAT      drop chains shorter than FLOAT fraction of the longest overlapping chain [0.50]\n       -W INT        discard a chain if seeded bases shorter than INT [0]\n       -m INT        perform at most INT rounds of mate rescues for each read [50]\n       -S            skip mate rescue\n       -P            skip pairing; mate rescue performed unless -S also in use\n       -e            discard full-length exact matches\n\nScoring options:\n\n       -A INT        score for a sequence match, which scales options -TdBOELU unless overridden [1]\n       -B INT        penalty for a mismatch [4]\n       -O INT[,INT]  gap open penalties for deletions and insertions [6,6]\n       -E INT[,INT]  gap extension penalty; a gap of size k cost '{-O} + {-E}*k' [1,1]\n       -L INT[,INT]  penalty for 5'- and 3'-end clipping [5,5]\n       -U INT        penalty for an unpaired read pair [17]\n\n       -x STR        read type. Setting -x changes multiple parameters unless overriden [null]\n                     pacbio: -k17 -W40 -r10 -A1 -B1 -O1 -E1 -L0  (PacBio reads to ref)\n                     ont2d: -k14 -W20 -r10 -A1 -B1 -O1 -E1 -L0  (Oxford Nanopore 2D-reads to ref)\n                     intractg: -B9 -O16 -L5  (intra-species contigs to ref)\n\nInput/output options:\n\n       -p            smart pairing (ignoring in2.fq)\n       -R STR        read group header line such as '@RG\\tID:foo\\tSM:bar' [null]\n       -H STR/FILE   insert STR to header if it starts with @; or insert lines in FILE [null]\n       -j            treat ALT contigs as part of the primary assembly (i.e. ignore <idxbase>.alt file)\n\n       -v INT        verbose level: 1=error, 2=warning, 3=message, 4+=debugging [3]\n       -T INT        minimum score to output [30]\n       -h INT[,INT]  if there are <INT hits with score >80% of the max score, output all in XA [5,200]\n       -a            output all alignments for SE or unpaired PE\n       -C            append FASTA/FASTQ comment to SAM output\n       -V            output the reference FASTA header in the XR tag\n       -Y            use soft clipping for supplementary alignments\n       -M            mark shorter split hits as secondary\n\n       -I FLOAT[,FLOAT[,INT[,INT]]]\n                     specify the mean, standard deviation (10% of the mean if absent), max\n                     (4 sigma from the mean if absent) and min of the insert size distribution.\n                     FR orientation only. [inferred]\n\nNote: Please read the man page for detailed description of the command line and options.\n",
            "id": "#bwa-mem-samtools.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "combinefiles.sh",
                            "entry": "zcat \"$@\" | gzip\n"
                        }
                    ]
                }
            ],
            "baseCommand": "bash",
            "arguments": [
                "combinefiles.sh"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2,
                        "shellQuote": false
                    },
                    "id": "#concat-gz-files.cwl/files"
                },
                {
                    "type": "string",
                    "id": "#concat-gz-files.cwl/output_filename"
                }
            ],
            "stdout": "$(inputs.output_filename)",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#concat-gz-files.cwl/output"
                }
            ],
            "id": "#concat-gz-files.cwl"
        },
        {
            "class": "ExpressionTool",
            "label": "Given a FASTQReadPairType returns a 2D array of the files contained within",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#FASTQReadPairType.yml/FASTQReadPairType"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#extract-named-file-pair-details.cwl/library"
                },
                {
                    "type": "string",
                    "id": "#extract-named-file-pair-details.cwl/platform"
                },
                {
                    "type": "#FASTQReadPairType.yml/FASTQReadPairType",
                    "id": "#extract-named-file-pair-details.cwl/read_pair"
                }
            ],
            "outputs": [
                {
                    "type": "string",
                    "id": "#extract-named-file-pair-details.cwl/read_group_header"
                },
                {
                    "type": "string",
                    "id": "#extract-named-file-pair-details.cwl/read_pair_name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    },
                    "id": "#extract-named-file-pair-details.cwl/reads"
                }
            ],
            "expression": "${\n  var readPairName = inputs.read_pair.name;\n  var readGroupHeader = \"@RG\" +\n    \"\\\\tID:\" + readPairName +\n    \"\\\\tLB:\" + inputs.library +\n    \"\\\\tPL:\" + inputs.platform +\n    \"\\\\tPU:\" + readPairName +\n    \"\\\\tSM:\" + readPairName;\n  return {\n    reads: [\n      inputs.read_pair.read1_files,\n      inputs.read_pair.read2_files,\n    ],\n    read_pair_name: readPairName,\n    read_group_header: readGroupHeader\n  };\n\n}\n",
            "id": "#extract-named-file-pair-details.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/fastqc:0.11.4"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "0.11.4"
                            ],
                            "package": "fastqc",
                            "https://schema.org/citation": "https://www.bioinformatics.babraham.ac.uk/projects/fastqc/"
                        }
                    ]
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "fastq",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--format"
                    },
                    "id": "#fastqc.cwl/format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#fastqc.cwl/input_fastq_file"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "--noextract",
                        "position": 2
                    },
                    "id": "#fastqc.cwl/noextract"
                },
                {
                    "type": "int",
                    "default": 1,
                    "doc": "The number of threads to use. The fastqc wrapper script requests 250MB of memory per thread, so keep this in line with any CWL ResourceRequirement",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--threads"
                    },
                    "id": "#fastqc.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*_fastqc.zip"
                    },
                    "id": "#fastqc.cwl/output_qc_report"
                }
            ],
            "baseCommand": "fastqc",
            "arguments": [
                {
                    "valueFrom": "$('/tmp')",
                    "prefix": "--dir",
                    "position": 5
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "-o",
                    "position": 5
                }
            ],
            "id": "#fastqc.cwl"
        },
        {
            "class": "ExpressionTool",
            "label": "Generates a set of file names for preprocessing steps based on an input sample name",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/sample_name"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#generate-sample-filenames.cwl/combined_reads_output_filenames"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/dedup_metrics_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/dedup_reads_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/fixedtag_reads_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/haplotypes_bam_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/hs_metrics_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/mapped_reads_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/raw_variants_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/recal_reads_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/recal_table_output_filename"
                },
                {
                    "type": "string",
                    "id": "#generate-sample-filenames.cwl/sorted_reads_output_filename"
                }
            ],
            "expression": "${\n  function makeFilename(base, suffix, extension) {\n    return base + '-' + suffix + '.' + extension;\n  }\n  var base = inputs.sample_name\n\n  return {\n    combined_reads_output_filenames: [\n      makeFilename(base, 'R1', 'fastq.gz'),\n      makeFilename(base, 'R2', 'fastq.gz'),\n    ],\n    mapped_reads_output_filename: makeFilename(base, 'mapped', 'bam'),\n    sorted_reads_output_filename: makeFilename(base, 'sorted', 'bam'),\n    dedup_reads_output_filename: makeFilename(base, 'dedup', 'bam'),\n    dedup_metrics_output_filename: makeFilename(base, 'dedup-metrics', 'out'),\n    recal_reads_output_filename: makeFilename(base, 'recal', 'bam'),\n    recal_table_output_filename: makeFilename(base, 'recal', 'table'),\n    raw_variants_output_filename: makeFilename(base, 'raw_variants', 'g.vcf'),\n    haplotypes_bam_output_filename:  makeFilename(base, 'haplotypes', 'bam'),\n    hs_metrics_output_filename: makeFilename(base, 'hs', 'txt'),\n    fixedtag_reads_output_filename: makeFilename(base, 'fixed_tags', 'bam')\n  };\n}\n",
            "id": "#generate-sample-filenames.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/picard:2.10.7"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "2.10.7"
                            ],
                            "package": "picard",
                            "https://schema.org/citation": "http://broadinstitute.github.io/picard"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "The bait interval file in picard interval_list format (from capture kit).",
                    "inputBinding": {
                        "prefix": "BAIT_INTERVALS=",
                        "shellQuote": false
                    },
                    "id": "#picard-CollectHsMetrics.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "doc": "The BAM or SAM file to collect metrics from.  Required.",
                    "inputBinding": {
                        "prefix": "I=",
                        "shellQuote": false
                    },
                    "id": "#picard-CollectHsMetrics.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The metrics output filename.",
                    "default": "hs_metrics.txt",
                    "inputBinding": {
                        "prefix": "O=",
                        "shellQuote": false
                    },
                    "id": "#picard-CollectHsMetrics.cwl/output_filename"
                },
                {
                    "type": "File",
                    "doc": "The reference sequences in fasta format.",
                    "inputBinding": {
                        "prefix": "R=",
                        "shellQuote": false
                    },
                    "id": "#picard-CollectHsMetrics.cwl/reference_sequence"
                },
                {
                    "type": "File",
                    "doc": "The target interval file in picard interval_list format (from capture kit).",
                    "inputBinding": {
                        "prefix": "TARGET_INTERVALS=",
                        "shellQuote": false
                    },
                    "id": "#picard-CollectHsMetrics.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#picard-CollectHsMetrics.cwl/output_hs_metrics_file"
                }
            ],
            "baseCommand": [
                "java",
                "-Xmx4g"
            ],
            "arguments": [
                {
                    "valueFrom": "/opt/picard/picard.jar",
                    "position": -1,
                    "prefix": "-jar"
                },
                {
                    "valueFrom": "CollectHsMetrics",
                    "position": 0
                }
            ],
            "id": "#picard-CollectHsMetrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/picard:2.10.7"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "2.10.7"
                            ],
                            "package": "picard",
                            "https://schema.org/citation": "http://broadinstitute.github.io/picard"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "One or more input SAM or BAM files to analyze. Must be coordinate sorted.",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "shellQuote": false
                    },
                    "id": "#picard-MarkDuplicates.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output metrics filename",
                    "default": "marked_dup_metrics.txt",
                    "inputBinding": {
                        "prefix": "METRICS_FILE=",
                        "shellQuote": false
                    },
                    "id": "#picard-MarkDuplicates.cwl/metrics_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output filename",
                    "default": "marked_duplicates.bam",
                    "inputBinding": {
                        "prefix": "OUTPUT=",
                        "shellQuote": false
                    },
                    "id": "#picard-MarkDuplicates.cwl/output_filename"
                },
                {
                    "type": "boolean",
                    "doc": "If true do not write duplicates to the output file instead of writing them with appropriate flags set.  (Default true).",
                    "default": true,
                    "inputBinding": {
                        "prefix": "REMOVE_DUPLICATES=",
                        "shellQuote": false
                    },
                    "id": "#picard-MarkDuplicates.cwl/remove_duplicates"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard-MarkDuplicates.cwl/output_dedup_bam_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.metrics_filename)"
                    },
                    "id": "#picard-MarkDuplicates.cwl/output_metrics_file"
                }
            ],
            "baseCommand": [
                "java"
            ],
            "arguments": [
                {
                    "valueFrom": "-Xmx4g",
                    "position": -2
                },
                {
                    "valueFrom": "/opt/picard/picard.jar",
                    "position": -1,
                    "prefix": "-jar"
                },
                {
                    "valueFrom": "MarkDuplicates",
                    "position": 0
                },
                {
                    "valueFrom": "CREATE_INDEX=True",
                    "position": 0
                }
            ],
            "id": "#picard-MarkDuplicates.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/picard:2.10.7"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "2.10.7"
                            ],
                            "package": "picard",
                            "https://schema.org/citation": "http://broadinstitute.github.io/picard"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "The BAM or SAM file to sort.  Required.",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "shellQuote": false
                    },
                    "id": "#picard-SortSam.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The sorted BAM or SAM output file.",
                    "default": "sorted.bam",
                    "inputBinding": {
                        "prefix": "OUTPUT=",
                        "shellQuote": false
                    },
                    "id": "#picard-SortSam.cwl/output_filename"
                },
                {
                    "type": "string",
                    "doc": "Sort order of output file  Required. Possible values: {unsorted, queryname, coordinate, duplicate}",
                    "default": "coordinate",
                    "inputBinding": {
                        "prefix": "SORT_ORDER=",
                        "shellQuote": false
                    },
                    "id": "#picard-SortSam.cwl/sort_order"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard-SortSam.cwl/sorted"
                }
            ],
            "baseCommand": [
                "java",
                "-Xmx4g"
            ],
            "arguments": [
                {
                    "valueFrom": "/opt/picard/picard.jar",
                    "position": -1,
                    "prefix": "-jar"
                },
                {
                    "valueFrom": "SortSam",
                    "position": 0
                }
            ],
            "id": "#picard-SortSam.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/trim-galore:0.4.4"
                },
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "version": [
                                "1.14"
                            ],
                            "package": "cutadapt",
                            "https://schema.org/citation": "https://dx.doi.org/10.14806/ej.17.1.200"
                        },
                        {
                            "version": [
                                "0.4.4"
                            ],
                            "package": "trimgalore",
                            "https://schema.org/citation": "https://www.bioinformatics.babraham.ac.uk/projects/trim_galore/"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--paired"
                    },
                    "id": "#trim_galore.cwl/paired"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#trim_galore.cwl/reads"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_trimming_report.txt"
                    },
                    "id": "#trim_galore.cwl/trim_reports"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_val_*.fq*"
                    },
                    "id": "#trim_galore.cwl/trimmed_reads"
                }
            ],
            "baseCommand": "trim_galore",
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "-o",
                    "position": 2
                }
            ],
            "id": "#trim_galore.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html"
    ]
}
